/*----------------------------------------------*/
//Author : Mudassar Khan
//Article: Export GridView with Images to Word, Excel and PDF Formats
//WebSite: http://www.aspsnippets.com
/*----------------------------------------------*/


using System;
using System.Collections.Generic;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;

using System.IO;
using System.Drawing;
using iTextSharp.text;
using iTextSharp.text.pdf;
using iTextSharp.tool.xml;

public partial class CS : System.Web.UI.Page
{
    protected void Page_Load(object sender, EventArgs e)
    {
        if (!this.IsPostBack)
        {
            this.BindGrid();
        }
    }

    private void BindGrid()
    {
        //Fetch the Current URL.
        Uri uri = Request.Url;

        //Generate Absolute Path for the Images folder.
        string folderUrl = string.Format("{0}://{1}{2}", uri.Scheme, uri.Authority, uri.AbsolutePath);
        folderUrl = folderUrl.Replace(Request.Url.Segments[Request.Url.Segments.Length - 1], "");
        folderUrl += "Images/";

        //Fetch the Images from Images Folder and generate Absolute Path.
        string[] filePaths = Directory.GetFiles(Server.MapPath("~/Images/"));
        List<System.Web.UI.WebControls.ListItem> files = new List<System.Web.UI.WebControls.ListItem>();
        foreach (string filePath in filePaths)
        {
            string fileName = Path.GetFileName(filePath);
            files.Add(new System.Web.UI.WebControls.ListItem(fileName, string.Concat(folderUrl, fileName)));
        }

        //Bind the GridView.
        gvFiles.DataSource = files;
        gvFiles.DataBind();
    }

    protected void ExportToWord(object sender, EventArgs e)
    {
        Response.Clear();
        Response.Buffer = true;
        Response.AddHeader("content-disposition", "attachment;filename=GridViewExport.doc");
        Response.Charset = "";
        Response.ContentType = "application/vnd.ms-word";
        using (StringWriter sw = new StringWriter())
        {
            HtmlTextWriter hw = new HtmlTextWriter(sw);

            //To Export all pages.
            gvFiles.AllowPaging = false;
            this.BindGrid();

            gvFiles.HeaderRow.BackColor = Color.White;
            foreach (TableCell cell in gvFiles.HeaderRow.Cells)
            {
                cell.BackColor = gvFiles.HeaderStyle.BackColor;
            }
            foreach (GridViewRow row in gvFiles.Rows)
            {
                row.BackColor = Color.White;
                foreach (TableCell cell in row.Cells)
                {
                    if (row.RowIndex % 2 == 0)
                    {
                        cell.BackColor = gvFiles.AlternatingRowStyle.BackColor;
                    }
                    else
                    {
                        cell.BackColor = gvFiles.RowStyle.BackColor;
                    }
                }
            }

            gvFiles.RenderControl(hw);

            Response.Output.Write(sw.ToString());
            Response.Flush();
            Response.End();
        }
    }

    protected void ExportToExcel(object sender, EventArgs e)
    {
        Response.Clear();
        Response.Buffer = true;
        Response.AddHeader("content-disposition", "attachment;filename=GridViewExport.xls");
        Response.Charset = "";
        Response.ContentType = "application/vnd.ms-excel";
        using (StringWriter sw = new StringWriter())
        {
            HtmlTextWriter hw = new HtmlTextWriter(sw);

            //To Export all pages.
            gvFiles.AllowPaging = false;
            this.BindGrid();

            gvFiles.HeaderRow.BackColor = Color.White;
            foreach (TableCell cell in gvFiles.HeaderRow.Cells)
            {
                cell.BackColor = gvFiles.HeaderStyle.BackColor;
            }
            foreach (GridViewRow row in gvFiles.Rows)
            {
                row.BackColor = Color.White;
                foreach (TableCell cell in row.Cells)
                {
                    if (row.RowIndex % 2 == 0)
                    {
                        cell.BackColor = gvFiles.AlternatingRowStyle.BackColor;
                    }
                    else
                    {
                        cell.BackColor = gvFiles.RowStyle.BackColor;
                    }
                }
            }

            gvFiles.RenderControl(hw);

            Response.Output.Write(sw.ToString());
            Response.Flush();
            Response.End();
        }
    }

    protected void ExportToPDF(object sender, EventArgs e)
    {
        Response.Clear();
        Response.Buffer = true;
        Response.AddHeader("content-disposition", "attachment;filename=GridViewExport.pdf");
        Response.Charset = "";
        Response.ContentType = "application/pdf";

        //To Export all pages.
        gvFiles.AllowPaging = false;
        this.BindGrid();

        using (StringWriter sw = new StringWriter())
        {
            using (HtmlTextWriter hw = new HtmlTextWriter(sw))
            {
                gvFiles.RenderControl(hw);
                using (StringReader sr = new StringReader(sw.ToString()))
                {
                    using (Document pdfDoc = new Document(PageSize.A4, 10f, 10f, 10f, 0f))
                    {
                        using (PdfWriter writer = PdfWriter.GetInstance(pdfDoc, Response.OutputStream))
                        {
                            pdfDoc.Open();
                            XMLWorkerHelper.GetInstance().ParseXHtml(writer, pdfDoc, sr);
                            pdfDoc.Close();
                            Response.Cache.SetCacheability(HttpCacheability.NoCache);
                            Response.Write(pdfDoc);
                            Response.End();
                        }
                    }
                }
            }
        }
    }

    public override void VerifyRenderingInServerForm(Control control)
    {
        /* Verifies that the control is rendered. */
    }
}
