'----------------------------------------------
'Author : Mudassar Khan
'Article: Export GridView with Images to Word, Excel and PDF Formats
'WebSite: http://www.aspsnippets.com
'----------------------------------------------

Imports System.IO
Imports System.Drawing
Imports iTextSharp.text
Imports iTextSharp.text.pdf
Imports iTextSharp.tool.xml

Partial Class VB
    Inherits System.Web.UI.Page
    Protected Sub Page_Load(ByVal sender As Object, ByVal e As EventArgs) Handles Me.Load
        If Not Me.IsPostBack Then
            Me.BindGrid()
        End If
    End Sub

    Private Sub BindGrid()
        'Fetch the Current URL.
        Dim uri As Uri = Request.Url

        'Generate Absolute Path for the Images folder.
        Dim folderUrl As String = String.Format("{0}://{1}{2}", uri.Scheme, uri.Authority, uri.AbsolutePath)
        folderUrl = folderUrl.Replace(Request.Url.Segments(Request.Url.Segments.Length - 1), "")
        folderUrl += "Images/"

        'Fetch the Images from Images Folder and generate Absolute Path.
        Dim filePaths As String() = Directory.GetFiles(Server.MapPath("~/Images/"))
        Dim files As List(Of System.Web.UI.WebControls.ListItem) = New List(Of System.Web.UI.WebControls.ListItem)()
        For Each filePath As String In filePaths
            Dim fileName As String = Path.GetFileName(filePath)
            files.Add(New System.Web.UI.WebControls.ListItem(fileName, String.Concat(folderUrl, fileName)))
        Next

        'Bind the GridView.
        gvFiles.DataSource = files
        gvFiles.DataBind()
    End Sub

    Protected Sub ExportToWord(ByVal sender As Object, ByVal e As EventArgs)
        Response.Clear()
        Response.Buffer = True
        Response.AddHeader("content-disposition", "attachment;filename=GridViewExport.doc")
        Response.Charset = ""
        Response.ContentType = "application/vnd.ms-word"

        Using sw As StringWriter = New StringWriter()
            Dim hw As HtmlTextWriter = New HtmlTextWriter(sw)

            'To Export all pages.
            gvFiles.AllowPaging = False
            Me.BindGrid()

            gvFiles.HeaderRow.BackColor = Color.White
            For Each cell As TableCell In gvFiles.HeaderRow.Cells
                cell.BackColor = gvFiles.HeaderStyle.BackColor
            Next
            For Each row As GridViewRow In gvFiles.Rows
                row.BackColor = Color.White
                For Each cell As TableCell In row.Cells
                    If row.RowIndex Mod 2 = 0 Then
                        cell.BackColor = gvFiles.AlternatingRowStyle.BackColor
                    Else
                        cell.BackColor = gvFiles.RowStyle.BackColor
                    End If
                Next
            Next

            gvFiles.RenderControl(hw)

            Response.Output.Write(sw.ToString())
            Response.Flush()
            Response.End()
        End Using
    End Sub

    Protected Sub ExportToExcel(sender As Object, e As EventArgs)
        Response.Clear()
        Response.Buffer = True
        Response.AddHeader("content-disposition", "attachment;filename=GridViewExport.xls")
        Response.Charset = ""
        Response.ContentType = "application/vnd.ms-excel"
        Using sw As StringWriter = New StringWriter()
            Dim hw As HtmlTextWriter = New HtmlTextWriter(sw)

            'To Export all pages.
            gvFiles.AllowPaging = False
            Me.BindGrid()

            gvFiles.HeaderRow.BackColor = Color.White
            For Each cell As TableCell In gvFiles.HeaderRow.Cells
                cell.BackColor = gvFiles.HeaderStyle.BackColor
            Next
            For Each row As GridViewRow In gvFiles.Rows
                row.BackColor = Color.White
                For Each cell As TableCell In row.Cells
                    If row.RowIndex Mod 2 = 0 Then
                        cell.BackColor = gvFiles.AlternatingRowStyle.BackColor
                    Else
                        cell.BackColor = gvFiles.RowStyle.BackColor
                    End If
                Next
            Next

            gvFiles.RenderControl(hw)

            Response.Output.Write(sw.ToString())
            Response.Flush()
            Response.End()
        End Using
    End Sub

    Protected Sub ExportToPDF(ByVal sender As Object, ByVal e As EventArgs)
        Response.Clear()
        Response.Buffer = True
        Response.AddHeader("content-disposition", "attachment;filename=GridViewExport.pdf")
        Response.Charset = ""
        Response.ContentType = "application/pdf"

        'To Export all pages.
        gvFiles.AllowPaging = False
        Me.BindGrid()

        Using sw As StringWriter = New StringWriter()
            Using hw As HtmlTextWriter = New HtmlTextWriter(sw)
                gvFiles.RenderControl(hw)
                Using sr As StringReader = New StringReader(sw.ToString())
                    Using pdfDoc As Document = New Document(PageSize.A4, 10.0F, 10.0F, 10.0F, 0.0F)
                        Using writer As PdfWriter = PdfWriter.GetInstance(pdfDoc, Response.OutputStream)
                            pdfDoc.Open()
                            XMLWorkerHelper.GetInstance().ParseXHtml(writer, pdfDoc, sr)
                            pdfDoc.Close()
                            Response.Cache.SetCacheability(HttpCacheability.NoCache)
                            Response.Write(pdfDoc)
                            Response.End()
                        End Using
                    End Using
                End Using
            End Using
        End Using
    End Sub

    Public Overrides Sub VerifyRenderingInServerForm(control As Control)
        ' Verifies that the control is rendered.
    End Sub
End Class
